#ifndef IDIALOG_H
#define IDIALOG_H

class XComApp;

class InputDialog : public FXDialogBox
{
    FXDECLARE(InputDialog)
protected:
    FXTextField*       input;
    FXDataTarget*      string_target;
private:
    InputDialog()
    {
        ;
    }
public:
    InputDialog(FXWindow*,FXString&,FXString,FXString,FXString label="",FXIcon *ic=NULL);
    virtual void create();
    long onCmdKeyPress(FXObject*,FXSelector,void*);
    FXString getText()
    {
        return input->getText();
    }
	void setText(const FXString& text)
	{
		input->setText(text);
	}
    void SelectAll()
    {
        input->setSelection(0,(input->getText()).length());
    };
    void CursorEnd()
    {
        input->onCmdCursorEnd(0,0,0);
    }
};
#endif
